@@ -10,16 +10,20 @@ class CDCS(RestClient):
     """
     
     # Import defined methods
+    from ._workspace import (get_workspaces, get_workspace,
+                             global_workspace)
+    
     from ._template import (get_template_managers, get_templates, get_template,
                             template_titles)
+
     from ._query import query
-    from ._record import (get_records, get_record, upload_record,
+    
+    from ._record import (get_records, get_record, upload_record, assign_records,
                           update_record, delete_record)
-    from ._blob import (get_blobs, get_blob, upload_blob, delete_blob,
+
+    from ._blob import (get_blobs, get_blob, upload_blob, delete_blob, assign_blobs,
                         get_blob_contents, download_blob)
-    from ._workspace import (get_workspaces, get_workspace,
-                             assign_record_workspace, assign_blob_workspace,
-                             global_workspace)
+    
     
     def testcall(self):
         """
